@@ -61,6 +61,9 @@ function(map)
       return(NULL)
     }else
     {
+      var_ronds <- map$x$calls[[idx_carte_ronds[length(idx_carte_ronds)]]]$args[[4]]$var_volume
+      var_classes <- map$x$calls[[idx_carte[length(idx_carte)]]]$args[[2]]$var_ratio
+      
       code_epsg <- map$x$calls[[idx_carte[length(idx_carte)]]]$args[[2]]$code_epsg
       dom <- map$x$calls[[idx_carte[length(idx_carte)]]]$args[[2]]$dom
       
@@ -70,41 +73,19 @@ function(map)
       
       for(i in 1:length(idx_carte))
       {
-        aa <- lapply(1:length(map$x$calls[[idx_carte[i]]]$args[[1]]), function(x) lapply(c(1:length(map$x$calls[[idx_carte[i]]]$args[[1]][[x]])), function(y) st_polygon(list(as.matrix(map$x$calls[[idx_carte[i]]]$args[[1]][[x]][[y]][[1]])))))
+        fond <- map$x$calls[[idx_carte[i]]]$args[[2]][1][[1]]
+        nom_col <- names(fond)[-which(names(fond)=="geometry")]
+        aa <- map$x$calls[[idx_carte[i]]]$args[[4]]$fillColor
+        fond <- cbind(fond,classe=aa)
+        fond <- fond[,c(nom_col,"classe","geometry")]
         
-        bb <- st_sf(geometry=st_sfc(NULL),crs="+init=epsg:4326 +proj=longlat +ellps=WGS84")
-        for(j in 1:length(aa))
-        {
-          bb <- rbind(bb,st_sf(geometry=st_sfc(st_multipolygon(lapply(1:length(aa[[j]]), function(x) aa[[j]][[x]]))),crs="+init=epsg:4326 +proj=longlat +ellps=WGS84"))
-        }
-        bb <- bb[-1,]
-        
-        if(any(substring(map$x$calls[[idx_carte[i]]]$args[[5]],1,3) %in% "<b>"))
-        {
-          var_classes <- map$x$calls[[idx_carte[i]]]$args[[2]]$var_ratio
-          
-          cc <- sapply(1:length(map$x$calls[[idx_carte[i]]]$args[[5]]), function(y) substring(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],25,str_locate_all(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],"<")[[1]][3]-1))
-          fond <- cbind(LIBELLE=cc,bb)
-          dd <- sapply(1:length(map$x$calls[[idx_carte[i]]]$args[[5]]), function(y) substring(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],str_locate_all(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],">")[[1]][11]+1,str_locate_all(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],"<")[[1]][12]-1))
-          dd <- as.numeric(str_replace_all(str_replace_all(dd,",",".")," ",""))
-          fond <- cbind(val=dd,fond)
-          ee <- map$x$calls[[idx_carte[i]]]$args[[4]]$fillColor
-          fond <- cbind(classe=ee,fond)
-          fond$var <- fond$val
-          fond <- fond[,c("LIBELLE","var","val","classe","geometry")]
-          names(fond) <- c("LIBELLE",var_classes,"val","classe","geometry")
-          
-          ff <- lapply(1:length(unique(fond$classe)), function(x) fond[fond$classe %in% rev(unique(fond$classe))[x],"classe"] <<- x)
-          rm(cc,dd,ee,ff)
-        }else
-        {
-          fond <- cbind(LIBELLE=map$x$calls[[idx_carte[i]]]$args[[5]],bb)
-        }
+        bb <- lapply(1:length(unique(fond$classe)), function(x) fond[fond$classe %in% rev(unique(fond$classe))[x],"classe"] <<- x)
         rm(aa,bb)
         
         fond <- st_transform(fond,paste0("+init=epsg:",code_epsg))
         
         list_fonds[[l]] <- fond
+        rm(fond)
         
         nom_fonds <- c(nom_fonds,map$x$calls[[idx_carte[i]]]$args[[2]]$nom_fond)
         
@@ -113,26 +94,33 @@ function(map)
       
       for(i in 1:length(idx_carte_ronds))
       {
-        var_ronds <- map$x$calls[[idx_carte_ronds[i]]]$args[[4]]$var_volume
-        dom <- map$x$calls[[idx_carte_ronds[i]]]$args[[4]]$dom
+        if(length(map$x$calls[[idx_carte_ronds[1]]]$args[[4]][[2]])==4) # representation elargie
+        {
+          if(i==1) # couche elargie
+          {
+            arg_fond <- 3
+            arg_donnees <- 4
+          }else # couche analyse
+          {
+            arg_fond <- 1 
+            arg_donnees <- 2
+          }
+        }else # representation normale
+        {
+          arg_fond <- 1 
+          arg_donnees <- 2
+        }
         
-        centres_ronds <- data.frame(lng=map$x$calls[[idx_carte_ronds[i]]]$args[[2]],lat=map$x$calls[[idx_carte_ronds[i]]]$args[[1]])
-        aa <- apply(centres_ronds,1, function(x) st_sf(geometry=st_sfc(st_point(x),crs="+init=epsg:4326 +proj=longlat +ellps=WGS84")))
-        bb <- do.call("rbind",aa)
-        cc <- st_transform(bb,paste0("+init=epsg:",map$x$calls[[idx_carte_ronds[i]]]$args[[4]]$code_epsg))
-        dd <- st_buffer(cc, map$x$calls[[idx_carte_ronds[i]]]$args[[3]])
+        centres_ronds <- map$x$calls[[idx_carte_ronds[i]]]$args[[4]][[2]][[arg_fond]]
+        donnees <- map$x$calls[[idx_carte_ronds[i]]]$args[[4]][[2]][[arg_donnees]][,c("CODE","LIBELLE",var_ronds)]
         
-        ee <- sapply(1:length(map$x$calls[[idx_carte_ronds[i]]]$args[[7]]), function(y) substring(map$x$calls[[idx_carte_ronds[i]]]$args[[7]][[y]],25,str_locate_all(map$x$calls[[idx_carte_ronds[i]]]$args[[7]][[y]],"<")[[1]][3]-1))
-        fond <- cbind(LIBELLE=ee,dd)
-        ff <- sapply(1:length(map$x$calls[[idx_carte_ronds[i]]]$args[[7]]), function(y) substring(map$x$calls[[idx_carte_ronds[i]]]$args[[7]][[y]],str_locate_all(map$x$calls[[idx_carte_ronds[i]]]$args[[7]][[y]],">")[[1]][11]+1,str_locate_all(map$x$calls[[idx_carte_ronds[i]]]$args[[7]][[y]],"<")[[1]][12]-1))
-        ff <- as.numeric(str_replace_all(str_replace_all(ff,",",".")," ",""))
-        fond <- cbind(VAR_VOLUME=ff,fond)
-        rm(aa,bb,cc,dd,ee,ff)
+        fond <- st_buffer(centres_ronds, map$x$calls[[idx_carte_ronds[i]]]$args[[3]])
+        fond <- cbind(donnees,fond)
+        fond <- st_sf(fond)
         
         col_bor <- map$x$calls[[idx_carte_ronds[i]]]$args[[6]]$color
         fond <- cbind(COL_BOR=col_bor,fond)
-        ronds_pl <- fond[,c("LIBELLE","VAR_VOLUME","COL_BOR","geometry")]
-        names(ronds_pl) <- c("LIBELLE",var_ronds,"COL_BOR","geometry")
+        ronds_pl <- fond[,c("CODE","LIBELLE",var_ronds,"COL_BOR","geometry")]
         rm(fond)
         
         list_fonds[[l]] <- ronds_pl
